#
# Copyright (c) 2013 Duo Security
# All Rights Reserved
#
#
__version__ = '1.0.0'


class CallError(Exception):
    """
    Errors with a one-to-one correspondence between local and
    RPC-serialized representation.
    """

    def __init__(self, error, error_args=None):
        self.error = error
        if not error_args:
            error_args = {}
        self.error_args = error_args
        super(CallError, self).__init__(error, error_args)

    def __eq__(self, other):
        return (self.error == other.error
                and self.error_args == other.error_args)

ERR_BAD_ARG = 'bad arg'
ERR_CONNECTION_LOST = 'connection lost'
ERR_MISSING_ARG = 'missing arg'
ERR_SERIALIZE_RESULT = 'cannot serialize result'
ERR_TIMEOUT = 'timeout'
ERR_UNKNOWN = 'unknown error'

from . import crypto
from . import net
from .net import (
    CallBadArgError,
    CallMissingArgError,
    ClientFactory,
    ClientProtocol,
    Protocol,
    ServerFactory,
    ServerProtocol,
    generate_call_id,
    inlineCallbacks,
)
