from cryptography.hazmat.bindings.openssl.binding import Binding

Depends = object()


def _duo_md5_new_wrapper(func):
    def md5_with_safe_guard(*args, **kwargs):
        """
        Caller must explicitly pass used_for_security=False
        or used_for_security=Depends as a kwarg.
        """
        used_for_security = kwargs.get('used_for_security', True)

        # If `hashlib.new` is invoked with any other digest besides md5 then return.
        # This maintains expected functionality for digests like hashlib.new('sha1', 'hello')
        # without having to worry about the `used_for_security` keyword.
        if (func.__module__ == "_hashlib" and func.__name__ == "new" and args[0] != "md5"):
            return func(*args, **kwargs)

        try:
            if (used_for_security not in (Depends, False)) and Binding.lib.FIPS_mode():
                raise ValueError('Must pass used_for_security=False or used_for_security=Depends to use MD5 when in FIPS mode')
        except ImportError:
            pass

        if 'used_for_security' in kwargs:
            del kwargs['used_for_security']

        result = func(*args, **kwargs)

        return result
    return md5_with_safe_guard
