#
# Copyright (c) 2011 Duo Security
# All Rights Reserved
#

try:
    import win32crypt
    PROTECT_ENABLED = True
except ImportError:
    PROTECT_ENABLED = False

import base64


__entropy = "AU$HPRO$Y"
CRYPTPROTECT_UI_FORBIDDEN = 0x01
CRYPTPROTECT_LOCAL_MACHINE = 0x04


class ProtectDisabledException(Exception):
    pass


def protect(plainText):
    """Protects a sensitive string, such as a password, for persistence.
    Currently only available if in certain environments.
    Check protect.PROTECT_ENABLED for availability."""

    if not PROTECT_ENABLED:
        raise ProtectDisabledException()

    description = u'win32crypto.py'
    reserved_field = None
    prompt_struct = None
    flags = CRYPTPROTECT_UI_FORBIDDEN | CRYPTPROTECT_LOCAL_MACHINE
    cipher_text = win32crypt.CryptProtectData(plainText, description, __entropy, reserved_field, prompt_struct, flags)
    return base64.b64encode(cipher_text)


def unprotect(cipher_text):
    """Unprotects a previously protected string.
    Currently only available if in certain environments.
    Check protect.PROTECT_ENABLED for availability."""

    if not PROTECT_ENABLED:
        raise ProtectDisabledException()

    cipher_text = base64.b64decode(cipher_text)
    reserved_field = None
    prompt_struct = None
    flags = CRYPTPROTECT_UI_FORBIDDEN | CRYPTPROTECT_LOCAL_MACHINE
    _, plainText = win32crypt.CryptUnprotectData(cipher_text, __entropy, reserved_field, prompt_struct, flags)
    return plainText
