#
# Copyright (c) 2011 Duo Security
# All Rights Reserved
#

import unittest
import sys
import argparse
import importlib
import platform
from meta import MetaTester
from timing import TimeLoggingTestRunner
from duoauthproxy.lib import fips_manager

if platform.system() == 'Windows':
    import os
    os.environ['PATH'] = os.environ['PATH'] + ';third-party\Python-2.7.14\Lib\site-packages\pywin32_system32;dist'
    sys.path.append('.')
    sys.path.append('test')


parser = argparse.ArgumentParser()
parser.add_argument("-f", "--fips", action="store_true", help="Only run the unit tests in FIPS mode")
parser.add_argument("-t", "--time", action="store_true", required=('--threshold' in sys.argv),
                    help="Time unit tests and record slow tests")
parser.add_argument("--threshold", type=float, default=0.3,
                    help="Threshold over which timed tests should be logged")
parser.add_argument("module", nargs='?', default=None, help="Module to run")
parser.add_argument("test", nargs='?', default=None, help="Test to run")
args = parser.parse_args()

if args.fips:
    fips_manager.enable()


module = None
test = None
if args.module:
    for prefix in ['test.', 'test.lib.', 'lib.', '']:
        try:
            module = importlib.import_module("{0}{1}".format(prefix, args.module))
        except ImportError as e:
            if e.message.find(args.module) != -1 and e.message.find("No module named") != -1:
                pass
            else:
                raise e
    if not module:
        raise Exception("Could not find specified module {0}".format(args.module))

if args.test:
    test = args.test

if args.time:
    runner = TimeLoggingTestRunner(slow_test_threshold=args.threshold)
else:
    runner = unittest.TextTestRunner()

if args.fips is True:
    result = MetaTester.run_in_fips_mode(module, test, runner)
else:
    result = MetaTester.run_in_non_fips_mode(module, test, runner)

# if the test run was a success, don't use a non-zero exit code
sys.exit(not result)
