import os
from subprocess import call, check_output, Popen, PIPE, STDOUT, CalledProcessError

from test.features.fixtures.install import base


class LinuxInstaller(base.Installer):
    def __init__(self):
        self.install_dir = os.path.join("/opt", "duoauthproxy")
        ap_version = base.get_authproxy_version()

        try:
            git_revision = base.get_commit_hash()
        except OSError:
            git_revision = ""

        source_dist_folder = "duoauthproxy-{0}-{1}-src".format(ap_version, git_revision)
        self.installer_name = os.path.join(source_dist_folder, "duoauthproxy-build", "install")
        self.authproxy_python = os.path.join(source_dist_folder, "duoauthproxy-build", "usr", "local", "bin", "python")

        super(LinuxInstaller, self).__init__()

    def start(self):
        self._run(call, [self.install_dir + "/bin/authproxyctl", "start"])

    def stop(self):
        self._run(call, [self.install_dir + "/bin/authproxyctl", "stop"])

    # The default restart limit for systemd is 5 times in 10 seconds. This sleep
    # helps make sure we don't hit that threshold.
    def restart(self):
        self._run(call, [self.install_dir + "/bin/authproxyctl", "restart"])

    def is_running(self):
        try:
            self._run(check_output, [self.install_dir + "/bin/authproxyctl", "status"])
            return True
        except CalledProcessError as e:
            print e.output
            return False

    def run_connectivity_tool(self):
        self._run(call, [self.install_dir + "/bin/authproxy_connectivity_tool"])

    def run_primary_only_tool(self, args=None, method=call):
        if not args:
            args = []
        return self._run(method, [self.install_dir + "/bin/authproxy_primary_only"] + args)

    def run_authproxy(self, args=None, method=call):
        if not args:
            args = []
        return self._run(method, [os.path.join(self.install_dir, "bin", "authproxy")] + args)

    def install(self):
        # set up a user and group to run the AP under
        self._run(call, ['useradd', 'apservice'])
        self._run(call, ['groupadd', 'lockeddown'])
        self._run(call, [self.installer_name,
                         "--install-dir", self.install_dir,
                         "--service-user", "duo_authproxy_svc",
                         "--log-group", "lockeddown",
                         "--create-init-script", "yes"])

    def uninstall(self):
        uninstall_script = os.path.join(self.install_dir, "uninstall")
        uninstall_process = self._run(Popen, [uninstall_script],
                                      stdout=PIPE, stdin=PIPE, stderr=STDOUT)
        uninstall_process.communicate(input="Yes")
