# pylint: disable=W0613

import os
from os.path import isfile
from os import environ
from subprocess import call

from test.features.fixtures.install import base


class ExeNotFound(Exception):
    pass


class WindowsInstaller(base.Installer):
    def __init__(self):
        install_base = environ['PROGRAMFILES']
        self.install_dir = os.path.join(install_base, "Duo Security Authentication Proxy")

        ap_version = base.get_authproxy_version()
        git_revision = base.get_commit_hash()
        self.installer_name = "duoauthproxy-{0}-{1}.exe".format(ap_version, git_revision)
        self.authproxy_python = os.path.join("windows_python.cmd")  # python executable with all the PATHs

        super(WindowsInstaller, self).__init__()

    def start(self):
        self._run(call, ["net", "start", "DuoAuthProxy"])

    def stop(self):
        self._run(call, ["net", "stop", "DuoAuthProxy"])

    def restart(self):
        self._run(call, ["net", "stop", "DuoAuthProxy"])
        self._run(call, ["net", "start", "DuoAuthProxy"])

    def is_running(self):
        return self._run(call, ["sc", "query", "DuoAuthProxy"]) == 0

    def run_connectivity_tool(self):
        self._run(call, [os.path.join(self.install_dir, "bin", "authproxy_connectivity_tool.exe")])

    def run_primary_only_tool(self, args=None, method=call):
        if not args:
            args = []
        return self._run(method, [os.path.join(self.install_dir, "bin", "authproxy_primary_only.exe")] + args)

    def run_authproxy(self, args=None, method=call):
        if not args:
            args = []
        return self._run(method, [os.path.join(self.install_dir, "bin", "authproxy.exe")] + args)

    def install(self):
        exe = self.installer_name
        if not isfile(exe):
            raise ExeNotFound("Could not find installer {0}".format(exe))
        self._run(call, [exe, "/S"])

    def uninstall(self):
        self._run(call, [self.install_dir + "//uninstall.exe", "/S"])
