from test.lib.mock_ldap_server import make_server_factory, LDAPServerFactory
from twisted.internet import reactor, defer
from duoauthproxy.modules import ad_client
from duoauthproxy.lib.config_provider import ConfigDict


@defer.inlineCallbacks
def main():
    """
    Set up a local LDAP server. This is analogous to an Active Directory
    domain controller. This gets configured in the AP's `ad_client` section.
    """
    instance = None
    server_port = 10389
    yield make_server_factory(
        server_port, LDAPServerFactory, ssl=False)

    # setting config items
    config_items = {
        'host': '127.0.0.1',
        'port': str(server_port),
        'service_account_username': 'adminer',
        'service_account_password': 'password!',
        'search_dn': 'CN=Users,DC=bongos,DC=test',
        'bind_dn': "CN=adminer adminer,CN=Users,DC=bongos,DC=test",
        'auth_type': 'plain',
        'timeout': '1'
    }

    config = ConfigDict(config_items)

    instance = ad_client.Module(config)

    yield instance.ldap_proxy()


if __name__ == '__main__':
    reactor.callLater(0, main)
    reactor.run()
