# https://twistedmatrix.com/documents/current/web/howto/using-twistedweb.html

import json
import os
import time

from twisted.web.server import Site

from twisted.web.resource import Resource
from twisted.internet import reactor, endpoints

from twisted.internet.ssl import CertificateOptions
import OpenSSL

CHECK_SUCCESS = {
    "stat": "OK",
    "response": {
        "time": time.time()
    }
}

PING_SUCCESS = {
    "stat": "OK",
    "response": {
        "time": time.time()
    }
}

PROXY_JOIN_SUCCESS = {
    "stat": "OK",
    "response": {
        "call_message_type": 0,
    },
}

PREAUTH_SUCCESS = {
    "stat": "OK",
    "response": {
        "result": "allow",
        "status": "Logging you in automatically...",
        "devices": [
            {
                "device": "DPFZRS9FB0D46QFTM891",
                "type": "phone",
                "number": "XXX-XXX-0100",
                "name": "",
                "capabilities": [
                    "auto",
                    "push",
                    "sms",
                    "phone",
                    "mobile_otp"
                ]
            },
            {
                "device": "DHEKH0JJIYC1LX3AZWO4",
                "type": "token",
                "name": "0"
            }
        ]
    }
}

AUTH_SUCCESS = {
}


class RestResource(Resource):
    isLeaf = False


class V1Resource(Resource):
    isLeaf = False


class V2Resource(Resource):
    isLeaf = False


class AuthResource(Resource):
    isLeaf = False


class PreAuth(Resource):
    isLeaf = True

    def render_POST(self, request):
        request.responseHeaders.addRawHeader(b"content-type", b"application/json")

        return json.dumps(PREAUTH_SUCCESS)


class Auth(Resource):
    isLeaf = True

    def render_POST(self, request):
        request.responseHeaders.addRawHeader(b"content-type", b"application/json")

        return json.dumps({"name": _get_username(request)})


class Check(Resource):
    isLeaf = True

    def render_GET(self, request):
        request.responseHeaders.addRawHeader(b"content-type", b"application/json")

        return json.dumps(CHECK_SUCCESS)


class Ping(Resource):
    isLeaf = True

    def render_GET(self, request):
        request.responseHeaders.addRawHeader(b"content-type", b"application/json")

        return json.dumps(PING_SUCCESS)


class ProxyJoin(Resource):
    isLeaf = True

    def render_POST(self, request):
        request.responseHeaders.addRawHeader(b"content-type", b"application/json")

        return json.dumps(PROXY_JOIN_SUCCESS)


def _get_username(request):
    x = json.loads(request.content.getvalue())

    return x['name']


def main():
    root = Resource()

    # v1
    rest = RestResource()
    v1 = V1Resource()

    # v2
    v2 = V2Resource()
    auth = AuthResource()

    # v1
    root.putChild('rest', rest)
    rest.putChild('v1', v1)
    v1.putChild('preauth', PreAuth())
    v1.putChild('auth', Auth())

    # v2
    root.putChild('auth', auth)
    auth.putChild('v2', v2)
    v2.putChild('check', Check())
    v2.putChild('ping', Ping())
    v2.putChild('proxy_join', ProxyJoin())

    factory = Site(root)

    key = OpenSSL.crypto.load_privatekey(OpenSSL.crypto.FILETYPE_PEM, open(os.path.join('test', 'features', 'fixtures', 'servers', 'fakeduo-localhost-key.pem'), 'rt').read())
    raw_cert = open(os.path.join('test', 'features', 'fixtures', 'servers', 'fakeduo-localhost-cert.pem'), 'rt').read()
    cert = OpenSSL.crypto.load_certificate(OpenSSL.crypto.FILETYPE_PEM, raw_cert)
    ctx = CertificateOptions(certificate=cert, privateKey=key)

    # use sudo because this is trying to use port 443
    endpoint = endpoints.SSL4ServerEndpoint(reactor, 443, ctx)
    endpoint.listen(factory)


if __name__ == '__main__':
    reactor.callLater(0, main)
    reactor.run()
