"""
This module contains wrappers around small twisted servers to be used as backing servers for testing proxying.
Behave has no support for Twisted so this allows us to run them without blocking the main behave process.
"""
import os
import sys
import subprocess

from behave import fixture


@fixture(name='fixture.ldap.server')
def backing_ldap_server(context):
    """
    Set up a process running a local LDAP server. After it's usage is done we will kill it.
    This allows us to do ayschronous operations outside of the regular behave process.
    """

    script_path = os.path.abspath(os.path.join(os.path.dirname(__file__), 'backing_ldap_server.py'))

    # We need to add the authproxy root directory to the python path to allow the subprocesses to access the test module
    authproxy_root_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), *['..'] * 4))

    context.backing_ldap_server_process = subprocess.Popen([context.installer.authproxy_python, script_path],
                                                           env={'PYTHONPATH': authproxy_root_dir})


@fixture(name='fixture.fake_duo.server')
def backing_fake_duo_server(context):
    """
    Set up a process running a fake duo cloud server.
    """

    script_path = os.path.abspath(os.path.join(os.path.dirname(__file__), 'fake_duo.py'))

    # We remove '' from the path list before making the colon separated env variable
    python_path = ":".join(sys.path[1:])

    # We need to add the authproxy root directory to the python path to allow the subprocesses to access the test module
    authproxy_root_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), *['..'] * 4))
    python_path = "{0}:{1}".format(authproxy_root_dir, python_path)

    context.backing_fake_duo_server_process = subprocess.Popen([context.installer.authproxy_python, script_path],
                                                               env={'PYTHONPATH': python_path})
