# pylint: disable=W0613,E0102,E0611
# flake8: noqa: F811

import time
import subprocess
import psutil
from behave import given, when, then

@then('the authproxy service is running')
def step_impl(context):
    assert context.installer.is_running() is True

@when('authproxy_primary_only is run with arguments "{args}"')
def step_impl(context, args):
    if args != "no arguments":
        args_array = args.split(' ')
    else:
        args_array = []
    try:
        context.output = context.installer.run_primary_only_tool(method=subprocess.check_output, args=(args_array + ['--non-interactive']))
    except Exception as e:
        print("Running process results in", e)
        assert False

@given('authproxy_primary_only is run in the background with arguments "{args}"')
def step_impl(context, args):
    if args != "no arguments":
        args_array = args.split(' ')
    else:
        args_array = []
    context.subprocess = context.installer.run_primary_only_tool(method=subprocess.Popen, args=(args_array + ['--non-interactive']))

@given('we wait {seconds} seconds for an authproxy to exist')
def step_impl(context, seconds):
    start_time = time.time()
    while time.time() - start_time < int(seconds) and not is_process_running(['authproxy', 'authproxy.exe']):
        time.sleep(1)

    assert is_process_running(['authproxy', 'authproxy.exe'])

@when('the subprocess is killed')
def step_impl(context):
    context.subprocess.kill()

@then('there is some authproxy running')
def step_impl(context):
    assert is_process_running(['authproxy', 'authproxy.exe'])

def is_process_running(names):
    found_process = False
    for process in psutil.process_iter():
        try:
            if process.name() in names:
                found_process = True
                process.kill()
                break
        except Exception:
            pass

    return found_process
