# pylint: disable=W0613,E0102,E0611
# flake8: noqa: F811
import os
import subprocess
from behave import given, then

@given('we run authproxy_support')
def step_impl(context):
    context.output = subprocess.check_output([os.path.join('bin', 'authproxy_support')])
    context.authproxy_zip = context.output.split(b" ")[-1].rstrip()

@then(u'we extract the zipped up bundle')
def step_impl(context):
    from zipfile import ZipFile

    with ZipFile(context.authproxy_zip, 'r') as z:
        z.extractall("temp-support")

@then(u'we have cleaned up temporary support files')
def step_impl(context):
    assert not os.path.isfile(os.path.join("conf", "cleaned_authproxy.cfg"))

@then(u'the scrubbed config file should not have any sensitive info')
def step_impl(context):
    cleaned_file = open(os.path.join('temp-support', 'conf', 'clean_authproxy.cfg'), 'r').read()

    assert "skey=****" in cleaned_file
    assert "radius_secret_1=****" in cleaned_file

    assert "skey=SUPERSECRETKEY" not in cleaned_file
    assert "radius_secret_1=SUPERSECRETRADIUSSECRET" not in cleaned_file

@then(u'we can see the log files')
def step_impl(context):
    assert os.path.isfile(os.path.join("temp-support", "log", "authproxy.log"))
    assert os.path.isfile(os.path.join("temp-support", "log", "connectivity_tool.log"))
