# pylint: disable=W0613,E0102,E0611
# flake8: noqa: F811
import os
import time
import signal
import subprocess

from test.features.fixtures import configs
from behave import given, then
from subprocess import Popen


@given('a config with {setting}')
def step_impl(context, setting):
    if setting == 'fips mode enabled':
        context.config_settings['fips_mode'] = 'True'
    if setting == 'logging auth events enabled':
        context.config_settings['log_auth_events'] = 'True'
    if setting == 'failmode of secure':
        context.config_settings['failmode'] = 'secure'
    if setting == 'api_host of badhost.local.duo':
        context.config_settings['api_host'] = 'badhost.local.duo'


@given('the authproxy is started with a {config_type}')
def step_impl(context, config_type):
    config = configs.get(config_type, **context.config_settings)

    context.installer.write_config(config)
    context.installer.restart()
    assert context.installer.is_running() is True

@given('the authproxy is started in primary only mode with a {config_type}')
def step_impl(context, config_type):
    config = configs.get(config_type, **context.config_settings)

    context.installer.write_config(config)
    context.installer.stop()
    subprocess = context.installer.run_authproxy(method=Popen, args=['--primary-only', '1'])
    context.pid = subprocess.pid
    time.sleep(5)


@then('the auth events log should be {created}')
def step_impl(context, created):
    is_created = created == 'created'
    file_found = os.path.isfile(context.installer.auth_events_log)
    assert file_found == is_created, "File found: {}  Expected: {}".format(
        file_found, is_created
    )


@then('in the {program} logs we should see "{text}"')
def step_impl(context, program, text):
    log_file = get_log_file(context, program)
    assert text in _get_log(log_file)


@then('in the {program} logs we should not see "{text}"')
def step_impl(context, program, text):
    log_file = get_log_file(context, program)
    assert text not in _get_log(log_file)

@then('in the output we should see "{text}"')
def step_impl(context, text):
    assert text in context.output

def get_log_file(context, program):
    if program == "authproxy":
        return context.installer.log_file
    elif program == "connectivity tool":
        return context.installer.tool_log_file
    else:
        raise ValueError("Unrecognized program {0}".format(program))

def _get_log(log_file):
    return open(log_file).read()
