#
# Copyright (c) 2012 Duo Security
# All Rights Reserved
#
"""
Test suite for handling Enrollment Codes
"""

import base64
import json
import unittest
from duoauthproxy.lib.enrollment import EnrollmentCode, EnrollmentError


class EnrollmentTestCase(unittest.TestCase):
    def setUp(self):
        data = {
            "api_host": "api-local.test-duosecurity.com",
            "enrollment_key": "supersecretenrollmentkey"
        }

        self.enrollment_code = base64.b64encode(json.dumps(data))

    def test_creates_an_enrollment(self):
        e = EnrollmentCode.create(self.enrollment_code)
        assert isinstance(e, EnrollmentCode)

    def test_invalid_enrollment_code(self):
        with self.assertRaises(EnrollmentError):
            EnrollmentCode.create('bad-enrollment-code-blob')

    def test_has_api_host(self):
        e = EnrollmentCode.create(self.enrollment_code)
        self.assertEqual(e.api_host, 'api-local.test-duosecurity.com')

    def test_has_enrollment_key(self):
        e = EnrollmentCode.create(self.enrollment_code)
        self.assertEqual(e.enrollment_key, 'supersecretenrollmentkey')


if __name__ == '__main__':
    unittest.main()
