#!/usr/bin/python
import ldaptor.md4
from .base import TestCase


class TestMD4(TestCase):
    def assert_hash_result(self, message, expected):
        hash_result = ldaptor.md4.new(message).digest().encode('hex')
        self.assertEqual(hash_result, expected.lower())

    def test_basic(self):
        self.assert_hash_result('', '31d6cfe0d16ae931b73c59d7e0c089c0')
        self.assert_hash_result('a', 'bde52cb31de33e46245e05fbdbd6fb24')
        self.assert_hash_result('abc', 'a448017aaf21d8525fc10ae87aa6729d')
        self.assert_hash_result('message digest', 'd9130a8164549fe818874806e1c7014b')
        self.assert_hash_result('abcdefghijklmnopqrstuvwxyz', 'd79e1c308aa5bbcdeea8ed63df412da9')
        self.assert_hash_result('ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789', '043f8582f241db351ce627e153e7f0e4')
        self.assert_hash_result('12345678901234567890123456789012345678901234567890123456789012345678901234567890', 'e33b4ddc9c38f2199c3e7b164fcc0536')

    def test_ldaptor_md4_not_using_hashlib(self):
        # Warn devs if ldaptor is upgraded to a version that attempts to use hashlib
        # for md4. We cannot do that in FIPS mode, ldaptor will need to be patched
        # to disable that functionality and force use of the internal/builtin
        # implementation
        self.assertFalse(hasattr(ldaptor.md4, 'hashlib'))
