#
# Copyright (c) 2012 Duo Security
# All Rights Reserved
#

from twisted.internet import defer
from twisted.trial.unittest import TestCase

import duoauthproxy.modules.mock_client
from duoauthproxy.lib.config_provider import ConfigDict


class TestModuleMockClient(TestCase):
    def setUp(self):
        self.username = 'someuser'
        self.password = 'somePassword!'
        self.config_items = {
            'username': self.username,
            'password': self.password,
        }
        config = ConfigDict(self.config_items)
        self.instance = duoauthproxy.modules.mock_client.Module(config)

    def tearDown(self):
        self.instance.stopService()

    def _test_cases(self, expect_radius_attrs=None):
        if expect_radius_attrs is None:
            expect_radius_attrs = {}

        @defer.inlineCallbacks
        def test1(username, password, expect_success):
            self.instance.pass_through_radius_attrs = dict(expect_radius_attrs)
            res = yield self.instance.authenticate(username,
                                                   password,
                                                   '10.2.68.17')
            self.assertEqual(res.success,
                             expect_success)
            self.assertEqual(res.radius_attrs,
                             expect_radius_attrs)

        test1(self.username,
              self.password,
              True)
        test1(self.username + ' not',
              self.password,
              False)
        test1(self.username,
              self.password + ' not',
              False)
        test1(self.username + ' not',
              self.password + ' not',
              False)

    def test_basic(self):
        self._test_cases()

    def test_pass_through_radius_attrs(self):
        self._test_cases({
            'Filter-Id': 96,
        })
