from ldaptor.protocols import pureldap
from twisted.trial.unittest import TestCase


class TestLDAPBindRequest(TestCase):
    def test_obscure_password_in_repr_method(self):
        """
        check that __repr__() does not stringify passwords, keys,
        and other sensitive info.
        """
        password = '$uperSecr3tp@ssw0rD293'
        request = pureldap.LDAPBindRequest(
            auth=password,
        )
        request.is_logging_insecure = False
        expected = "LDAPBindRequest(version=3, dn='', auth='*****', sasl=False)"
        actual = repr(request)
        self.assertEqual(actual, expected)

    def test_plaintext_password_in_repr_method(self):
        """
        check that __repr__() does not stringify passwords, keys,
        and other sensitive info.
        """
        password = '$uperSecr3tp@ssw0rD293'
        request = pureldap.LDAPBindRequest(
            auth=password,
        )
        request.is_logging_insecure = True
        expected = "LDAPBindRequest(version=3, dn='', auth='{0}', sasl=False)".format(password)
        actual = repr(request)
        self.assertEqual(actual, expected)


if __name__ == '__main__':
    import unittest
    unittest.main()
