
from duoauthproxy.lib.validation.connectivity.connectivity_results import (
    ConfigCheckResult,
)
from duoauthproxy.lib.validation.config.config_results import (
    UnexpectedKey,
    InvalidValue,
)
from duoauthproxy.lib.config_provider import ConfigDict
from duoauthproxy.lib.validation.config.check import duo_only_client
from ....base import TestCase


class TestCheckDuoOnlyClientConfig(TestCase):
    """
    Tests the [duo_only_client] config section tester module.
    """
    def setUp(self):
        super(TestCheckDuoOnlyClientConfig, self).setUp()
        self.BASIC_CONFIG_INPUT = ConfigDict({})

    def test_good_basic_config(self):
        """A usual [duo_only_client] has no fields"""
        config = self.BASIC_CONFIG_INPUT
        result = duo_only_client.check_duo_only_client(config)
        self.assert_results_equal(result, ConfigCheckResult([]))

    def test_good_inherited_config(self):
        """A [duo_only_client] config can inherit a few fields from [main]"""
        config = ConfigDict({
            'debug': 'True',
        })
        result = duo_only_client.check_duo_only_client(config)
        self.assert_results_equal(result, ConfigCheckResult([]))

    def test_bad_config(self):
        """There should be no keys explicitly given to a [duo_only_client] config,
        aside from what may be passed down from [main]"""
        config = ConfigDict({
            'radius_ip_1': 'thiskeydoesntbelonghere',
            'debug': '',
            'http_ca_certs_file': '/nonexistent/file/path',
        })
        result = duo_only_client.check_duo_only_client(config)
        expected_result = ConfigCheckResult([
            UnexpectedKey(key='radius_ip_1'),
            InvalidValue(key='debug', value=''),
            InvalidValue(key='http_ca_certs_file', value='/nonexistent/file/path'),
        ])
        self.assert_results_equal(expected_result, result)

    def assert_results_equal(self, expected_result, actual_result):
        self.assertEqual(expected_result, actual_result,
                         "{0} and {1} should be equal".format(
                             expected_result, actual_result))


if __name__ == '__main__':
    import unittest
    unittest.main()
