from duoauthproxy.lib.validation.config.config_results import InvalidValue
from duoauthproxy.lib.validation.connectivity.connectivity_results import \
    ConfigCheckResult

from duoauthproxy.lib.config_provider import ConfigDict
from duoauthproxy.lib.validation.config.check import http_proxy
from ....base import TestCase


class TestCheckHTTPProxyConfig(TestCase):
    """
    Tests the [http_proxy] config section tester module.
    """
    def setUp(self):
        super(TestCheckHTTPProxyConfig, self).setUp()
        self.BASIC_CONFIG_INPUT = ConfigDict({
            'api_host': 'api-12345678.test.duosecurity.com',
        })

    def test_basic_config(self):
        config = self.BASIC_CONFIG_INPUT
        result = http_proxy.check_http_proxy(config)
        self.assertEqual(result, ConfigCheckResult([]))

    def test_full_good_config(self):
        config = ConfigDict({
            'api_host': 'api-12345678.test.duosecurity.com',
            'port': '1234',
            'client_ip': '127.0.0.1',
            'interface': '127.0.0.1',
        })

        expected_result = ConfigCheckResult([])
        actual_result = http_proxy.check_http_proxy(config)
        self.assert_results_equal(expected_result, actual_result)

    def test_good_ip_range(self):
        config = self.BASIC_CONFIG_INPUT

        for ip_format in ('127.0.0.1', '127.0.0.1/32', '127.0.0.1/8',
                          '127.0.0.1/255.255.255.128', '127.0.0.1,127.0.0.2',
                          '127.0.0.1, 127.0.0.2',
                          '127.0.0.1/24, 127.2.0.0/255.255.0.0',
                          '2001:0db8:85a3:0000:0000:8a2e:0370:7334',
                          '2001:0db8:85a3:0000:0000:8a2e:0370:7334/64',
                          '2001:0db8:85a3:0000:0000:8a2e:0370:7334,2001:0db8:85a3:0000:0000:8a2e:0370:7335',
                          '2001:0db8:85a3:0000:0000:8a2e:0370:7334-2001:0db8:85a3:0000:0000:8a2e:0370:7335',
                          ):
            config['client_ip'] = ip_format
            result = http_proxy.check_http_proxy(config)
            expected_result = ConfigCheckResult([])
            self.assert_results_equal(expected_result, result)

    def test_bad_ip_range(self):
        config = self.BASIC_CONFIG_INPUT

        for ip_format in ('127.0.0.1.0', '127.0.0.1/33', '127.0.0.1//8',
                          '1270.0.1/255.255.255.128', '127.0.0.1,127.0.0',
                          '127,0.0.1/', '127.0.o.1,127.2.0',
                          '127.0.0.1-3', '1270.0.0.1', '127.0.0.1-127.0.0',
                          '2001:0db8:85a3;0000:0000:8a2e:0370:7334',
                          '2001:0db8:85a3:0000:8a2e:0370:7334/64',
                          '2001:0db8:85a3;0000:0000:8a2e:0370:7334/200',
                          '2001:0db8:85a3:0000:0000:8a2e:0370:7334.2001:0db8:85a3:0000:0000:8a2e:0370:7335',
                          '2001:0db8:85a3:0000:0000:8a2e:0370:7334-2001:0db8:85:a3:0000:0000:8a2e:0370:7335',
                          ):
            config['client_ip'] = ip_format
            result = http_proxy.check_http_proxy(config)
            expected_result = ConfigCheckResult([
                InvalidValue(key='client_ip', value=ip_format)
            ])
            self.assert_results_equal(expected_result, result)

    def assert_results_equal(self, expected_result, actual_result):
        self.assertEqual(expected_result, actual_result,
                         "{0} and {1} should be equal".format(
                             expected_result, actual_result))
