from duoauthproxy.lib.validation.config.config_results import InvalidValue
from duoauthproxy.lib.validation.connectivity.connectivity_results import \
    ConfigCheckResult

from duoauthproxy.lib.config_provider import ConfigDict
from duoauthproxy.lib.validation.config.check import radius_server_challenge
from ....base import TestCase


class TestCheckRadiusServerChallengeConfig(TestCase):
    """
    Tests the [radius_server_challenge] config section tester module.
    """

    def setUp(self):
        super(TestCheckRadiusServerChallengeConfig, self).setUp()
        self.BASIC_CONFIG_INPUT = ConfigDict({
            'ikey': 'DI000000000000000000',
            'skey': 'thisisntarealskeybutitcanplaysoneonthetv',
            'api_host': 'api-12345678.test.duosecurity.com',
            'radius_ip_1': '127.0.0.1',
            'radius_secret_1': 'radius_secret',
        })

    def test_basic_config(self):
        result = radius_server_challenge.check_radius_server_challenge(
            self.BASIC_CONFIG_INPUT)
        self.assertEqual(result, ConfigCheckResult([]))

    def test_full_good_config(self):
        config = ConfigDict({
            'ikey': 'DI000000000000000000',
            'skey': 'thisisntarealskeybutitcanplaysoneonthetv',
            'api_host': 'api-12345678.test.duosecurity.com',
            'radius_ip_1': '127.0.0.1',
            'radius_secret_1': 'radius_secret',
            'client': 'radius_client',
            'radius_ip_5': '127.0.0.5',
            'radius_secret_5': 'somesecret',
            'radius_ip_2': '127.0.0.2',
            'radius_secret_protected_2': 'aimcwaefwad',
            'prompt_format': 'html',
            'enroll_challenge': 'false',
            'api_timeout': 20,
            'failmode': 'secure',
            'interface': '127.0.0.100',
            'pass_through_attr_names': 'NAS-Identifier',
            'pass_through_all': 'true',
            'exempt_username_1': 'some_user',
            'exempt_username_3': 'some_other_user',
            'pw_codec': 'latin-1'
        })

        expected_result = ConfigCheckResult([])
        actual_result = radius_server_challenge.check_radius_server_challenge(config)
        self.assert_results_equal(expected_result, actual_result)

    def test_invalid_prompt_format(self):
        invalid_prompt_format = 'invalid_prompt_format'
        expected_result = ConfigCheckResult([
            InvalidValue(key='prompt_format', value=invalid_prompt_format)
        ])

        self.BASIC_CONFIG_INPUT['prompt_format'] = invalid_prompt_format
        actual_result = radius_server_challenge.check_radius_server_challenge(
            self.BASIC_CONFIG_INPUT)
        self.assert_results_equal(expected_result, actual_result)

    def test_invalid_enroll_challenge(self):
        invalid_enroll_challenge = ''
        expected_result = ConfigCheckResult([
            InvalidValue(key='enroll_challenge', value=invalid_enroll_challenge)
        ])

        self.BASIC_CONFIG_INPUT['enroll_challenge'] = invalid_enroll_challenge
        actual_result = radius_server_challenge.check_radius_server_challenge(
            self.BASIC_CONFIG_INPUT)
        self.assert_results_equal(expected_result, actual_result)

    def assert_results_equal(self, expected_result, actual_result):
        self.assertEqual(expected_result, actual_result,
                         "{0} and {1} should be equal".format(
                             expected_result, actual_result))


if __name__ == '__main__':
    import unittest
    unittest.main()
