from duoauthproxy.lib.validation.config.config_results import InvalidValue
from duoauthproxy.lib.validation.connectivity.connectivity_results import \
    ConfigCheckResult

from duoauthproxy.lib.config_provider import ConfigDict
from duoauthproxy.lib.validation.config.check import radius_server_concat
from ....base import TestCase


class TestCheckRadiusServerConcatConfig(TestCase):
    """
    Tests the [radius_server_concat] config section tester module.
    """

    def setUp(self):
        super(TestCheckRadiusServerConcatConfig, self).setUp()
        self.BASIC_CONFIG_INPUT = ConfigDict({
            'ikey': 'DI000000000000000000',
            'skey': 'thisisntarealskeybutitcanplaysoneonthetv',
            'api_host': 'api-12345678.test.duosecurity.com',
            'radius_ip_1': '127.0.0.1',
            'radius_secret_1': 'radius_secret',
        })

    def test_basic_config(self):
        result = radius_server_concat.check_radius_server_concat(
            self.BASIC_CONFIG_INPUT)
        self.assertEqual(result, ConfigCheckResult([]))

    def test_full_good_config(self):
        config = ConfigDict({
            'ikey': 'DI000000000000000000',
            'skey': 'thisisntarealskeybutitcanplaysoneonthetv',
            'api_host': 'api-12345678.test.duosecurity.com',
            'radius_ip_1': '127.0.0.1',
            'radius_secret_1': 'radius_secret',
            'client': 'radius_client',
            'radius_ip_5': '127.0.0.5',
            'radius_secret_5': 'somesecret',
            'radius_ip_2': '127.0.0.2',
            'radius_secret_protected_2': 'aimcwaefwad',
            'api_timeout': '20',
            'failmode': 'secure',
            'interface': '127.0.0.100',
            'delimiter': '-',
            'pass_through_attr_names': 'NAS-Identifier',
            'pass_through_all': 'true',
            'exempt_username_1': 'some_user',
            'exempt_username_3': 'some_other_user',
            'pw_codec': 'latin-1'
        })

        expected_result = ConfigCheckResult([])
        actual_result = radius_server_concat.check_radius_server_concat(config)
        self.assert_results_equal(expected_result, actual_result)

    def test_invalid_delimiter(self):
        config = self.BASIC_CONFIG_INPUT
        config['delimiter'] = ''
        expected_result = ConfigCheckResult([
            InvalidValue(key='delimiter', value='')
        ])

        actual_result = radius_server_concat.check_radius_server_concat(config)
        self.assert_results_equal(expected_result, actual_result)

    def assert_results_equal(self, expected_result, actual_result):
        self.assertEqual(expected_result, actual_result,
                         "{0} and {1} should be equal".format(
                             expected_result, actual_result))
