from duoauthproxy.lib.validation.connectivity.connectivity_results import \
    ConfigCheckResult

from duoauthproxy.lib.config_provider import ConfigDict
from duoauthproxy.lib.validation.config.check import radius_server_duo_only
from ....base import TestCase


class TestCheckRadiusServerDuoOnlyConfig(TestCase):
    """
    Tests the [radius_server_duo_only] config section tester module.
    """

    def setUp(self):
        super(TestCheckRadiusServerDuoOnlyConfig, self).setUp()
        self.BASIC_CONFIG_INPUT = ConfigDict({
            'ikey': 'DI000000000000000000',
            'skey': 'thisisntarealskeybutitcanplaysoneonthetv',
            'api_host': 'api-12345678.test.duosecurity.com',
            'radius_ip_1': '127.0.0.1',
            'radius_secret_1': 'radius_secret',
        })

    def test_basic_config(self):
        result = radius_server_duo_only.check_radius_server_duo_only(
            self.BASIC_CONFIG_INPUT)
        self.assertEqual(result, ConfigCheckResult([]))

    def test_full_good_config(self):
        config = ConfigDict({
            'ikey': 'DI102030405060708090',
            'skey': 'ThIsIsntAREALskeybutitcanplaysoneonthetv',
            'api_host': 'justahostname',
            'radius_ip_1': '127.0.0.1',
            'radius_secret_1': 'r',
            'client': 'duo_only_client',
            'radius_ip_5': '127.0.0.5',
            'radius_secret_5': 'somesecret',
            'radius_ip_2': '127.0.0.2',
            'radius_secret_protected_2': 'aimcwaefwad',
            'api_timeout': '20',
            'failmode': 'secure',
            'interface': '127.0.0.100',
            'pass_through_attr_names': 'NAS-Identifier,Calling-Station-Id',
            'pass_through_all': 'false',
            'exempt_username_1': 'some_user',
            'exempt_username_3': 'some_other_user',
            'pw_codec': 'utf-8'
        })

        expected_result = ConfigCheckResult([])
        actual_result = radius_server_duo_only.check_radius_server_duo_only(config)
        self.assert_results_equal(expected_result, actual_result)

    def assert_results_equal(self, expected_result, actual_result):
        self.assertEqual(expected_result, actual_result,
                         "{0} and {1} should be equal".format(
                             expected_result, actual_result))
