from duoauthproxy.lib.validation.config.config_results import InvalidValue
from duoauthproxy.lib.validation.connectivity.connectivity_results import \
    ConfigCheckResult

from duoauthproxy.lib.config_provider import ConfigDict
from duoauthproxy.lib.validation.config.check import radius_server_eap
from ....base import TestCase
from ....base import MockConfigTestToolbox


class TestCheckRadiusServerEAPConfig(TestCase):
    """
    Tests the [radius_server_eap] config section tester module.
    """

    def setUp(self):
        super(TestCheckRadiusServerEAPConfig, self).setUp()
        self.BASIC_CONFIG_INPUT = ConfigDict({
            'ikey': 'DI000000000000000000',
            'skey': 'thisisntarealskeybutitcanplaysoneonthetv',
            'api_host': 'api-12345678.test.duosecurity.com',
            'radius_ip_1': '127.0.0.1',
            'radius_secret_1': 'radius_secret',
            'certs': 'this/is/a/good.path',
            'pkey': 'another/good.path',
        })

    def test_basic_config(self):
        result = radius_server_eap.check_radius_server_eap(
            self.BASIC_CONFIG_INPUT, toolbox=MockConfigTestToolbox())
        self.assertEqual(result, ConfigCheckResult([]))

    def test_full_good_config(self):
        config = ConfigDict({
            'ikey': 'DI000000000000000000',
            'skey': 'thisisntarealskeybutitcanplaysoneonthetv',
            'api_host': 'api-12345678.test.duosecurity.com',
            'radius_ip_1': '127.0.0.1',
            'radius_secret_1': 'radius_secret',
            'client': 'radius_client',
            'radius_ip_5': '127.0.0.5',
            'radius_secret_5': 'somesecret',
            'radius_ip_2': '127.0.0.2',
            'radius_secret_protected_2': 'aimcwaefwad',
            'failmode': 'secure',
            'certs': 'this/is/a/good.path',
            'pkey': 'another/good.path',
            'factors': 'phone,push',
            'prompt': 'put your password here: ',
            'concat_mode': 'False',
            'delimiter': '$',
            'pass_through_attr_names': 'NAS-Identifier,Calling-Station-Id',
            'pw_codec': 'utf-8',
            'client_ip_attr': 'some-random-id'
        })

        expected_result = ConfigCheckResult([])
        actual_result = radius_server_eap.check_radius_server_eap(config, toolbox=MockConfigTestToolbox())
        self.assert_results_equal(expected_result, actual_result)

    def test_concat_mode_key_replacement(self):
        config = ConfigDict({
            'ikey': 'DI000000000000000000',
            'skey': 'thisisntarealskeybutitcanplaysoneonthetv',
            'api_host': 'api-12345678.test.duosecurity.com',
            'radius_ip_1': '127.0.0.1',
            'radius_secret_1': 'radius_secret',
            'client': 'radius_client',
            'certs': 'this/is/a/good.path',
            'pkey': 'another/good.path',
            'factors': 'phone,push',
            'prompt': 'put your password here: ',
            'concat_mode': 'False',
        })
        expected_result = ConfigCheckResult([])
        actual_result = radius_server_eap.check_radius_server_eap(config, toolbox=MockConfigTestToolbox())
        self.assert_results_equal(expected_result, actual_result)

    def test_invalid_path(self):
        config = self.BASIC_CONFIG_INPUT
        config['certs'] = 'this/is/a/bad.path'
        config['pkey'] = 'another/bad.path'
        expected_result = ConfigCheckResult([
            InvalidValue(key='certs', value='this/is/a/bad.path'),
            InvalidValue(key='pkey', value='another/bad.path'),
        ])

        actual_result = radius_server_eap.check_radius_server_eap(config)
        self.assert_results_equal(expected_result, actual_result)

    def test_interface_present(self):
        config = self.BASIC_CONFIG_INPUT
        config['interface'] = '127.0.0.1'
        expected_result = ConfigCheckResult([])

        actual_result = radius_server_eap.check_radius_server_eap(config, toolbox=MockConfigTestToolbox())
        self.assert_results_equal(expected_result, actual_result)

    def assert_results_equal(self, expected_result, actual_result):
        self.assertEqual(expected_result, actual_result,
                         "{0} and {1} should be equal".format(
                             expected_result, actual_result))
