#
# Copyright (c) 2018 Duo Security
# All Rights Reserved
#

import unittest


from duoauthproxy.lib.validation.config import config_value_tools


class TestConfigValueToolsDefinedSet(unittest.TestCase):
    def test_in_set_success(self):
        value = 'some_value'
        valid_options = ['some_value', 'good', 'ok']
        self.assertTrue(config_value_tools.is_value_in_defined_set(value, valid_options),
                        'Expected success testing value {0} in options {1}'.format(value, valid_options))

    def test_not_in_set_failure(self):
        value = 'some_value'
        valid_options = ['nope', 'no', 'nein']
        self.assertFalse(config_value_tools.is_value_in_defined_set(value, valid_options),
                         'Expected failure testing value {0} in options {1}'.format(value, valid_options))

    def test_blank_set_failure(self):
        value = 'some_value'
        valid_options = []
        self.assertFalse(config_value_tools.is_value_in_defined_set(value, valid_options),
                         'Expected failure testing value {0} in empty set of options')

    def test_blank_value_failure(self):
        value = ''
        valid_options = [None]

        self.assertFalse(config_value_tools.is_value_in_defined_set(value, valid_options),
                         'Expected failure for blank value')

    def test_is_cipher_list_failure(self):
        for bad_val in ['', 'NOT-A-CIPHER', 'SHA1+', 'SHA1+BAD', 'ALL:@STRENTH',
                        '!aNULL']:
            self.assertFalse(config_value_tools.is_cipher_list(bad_val))

    def test_is_cipher_list_success(self):
        for good_val in ['DEFAULT', 'PSK', 'aRSA', '!LOW:MEDIUM:HIGH', 'ALL:!aNULL',
                         'ALL:@STRENGTH', 'ALL:!EXPORT:!LOW:!aNULL:!eNULL:!SSLv2'
                         'RC4-SHA,' 'ALL:!EXPOT']:
            self.assertTrue(config_value_tools.is_cipher_list(good_val))

    def test_transform_creates_match(self):
        value = 'hi'
        valid_options = ['hi-appended_data']

        self.assertTrue(config_value_tools.is_value_in_defined_set(value, valid_options, transform=lambda x: x + '-appended_data'),
                        'Expected success test value {0} in options {1} when transform applied.'.format(value, valid_options))

    def test_transform_removes_match(self):
        value = 'hi'
        valid_options = ['hi']

        self.assertFalse(config_value_tools.is_value_in_defined_set(value, valid_options, transform=str.upper),
                         'Expected failed test with value {0} in options {1} when transform applied.'.format(value, valid_options))


if __name__ == '__main__':
    unittest.main()
