#
# Copyright (c) 2018 Duo Security
# All Rights Reserved
#

import unittest

from duoauthproxy.lib.validation.config import ldap_tools
from duoauthproxy.lib.config_provider import ConfigDict

BASE_CONFIG = ConfigDict({
    'valid_dn': 'cn=totally,ou=valid,dc=distinguishedname',
    'invalid_dn': 'this isnt a dn',
    'valid_filter': '(&(username=*foo*)(primaryGroupID=513))',
    'invalid_filter': 'not a filter'
})


class TestLdapToolsDN(unittest.TestCase):
    def test_success(self):
        test_key = 'valid_dn'
        self.assertTrue(ldap_tools.is_ldap_dn(BASE_CONFIG, test_key), 'Expected success for dn {0}'.format(test_key))

    def test_bad_dn_failure(self):
        test_key = 'invalid_dn'
        self.assertFalse(ldap_tools.is_ldap_dn(BASE_CONFIG, test_key), 'Expected failure for non-dn {0}'.format(test_key))

    def test_nonexistent_failure(self):
        test_key = 'not_a_key'
        self.assertFalse(ldap_tools.is_ldap_dn(BASE_CONFIG, test_key),
                         'Expected failure for non-existent key {0}'.format(test_key))


class TestLdapToolsFilter(unittest.TestCase):
    def test_success(self):
        test_key = 'valid_filter'
        self.assertTrue(ldap_tools.is_ldap_filter(BASE_CONFIG, test_key), 'Expected success for filter {0}'.format(test_key))

    def test_bad_filter_failure(self):
        test_key = 'invalid_filter'
        self.assertFalse(ldap_tools.is_ldap_filter(BASE_CONFIG, test_key), 'Expect failure for non-filter {0}'.format(test_key))

    def test_nonexistent_failure(self):
        test_key = 'not_a_key'
        self.assertFalse(ldap_tools.is_ldap_filter(BASE_CONFIG, test_key),
                         'Expected failure for non-existent key {0}'.format(test_key))


if __name__ == '__main__':
    unittest.main()
