#
# Copyright (c) 2018 Duo Security
# All Rights Reserved
#

import unittest

from duoauthproxy.lib.validation.config import type_tools
from duoauthproxy.lib.config_provider import ConfigDict


BASE_CONFIG = ConfigDict({
    'string_key': 'string_value',
    'empty_string_key': '',
    'int_key': '5',
    'not_int_key': 'five',
    'bool_key_true': 'true',
    'bool_key_false': 'false',
    'bool_key_num_zero': '0',
    'bool_key_num_one': '1',
    'bool_key_num_two': '2',
    'bool_key_word_zero': 'zero',
    'not_bool_key': 'fudgiecakes'
})


class TestTypeToolsStringable(unittest.TestCase):
    def test_success(self):
        test_key = 'string_key'
        self.assertTrue(type_tools.is_stringable(BASE_CONFIG, test_key), 'Expect success for key {0}'.format(test_key))

    def test_nonexistent_key_failure(self):
        test_key = 'doesnt_exist'
        self.assertFalse(type_tools.is_stringable(BASE_CONFIG, test_key),
                         'Expect failure for non-existent key {0}'.format(test_key))

    def test_empty_string_allowed(self):
        test_key = 'empty_string_key'
        self.assertTrue(type_tools.is_stringable(BASE_CONFIG, test_key, True),
                        'Expect success for key {0}'.format(test_key))

    def test_empty_string_disallowed(self):
        test_key = 'empty_string_key'
        self.assertFalse(type_tools.is_stringable(BASE_CONFIG, test_key),
                         'Expect failure for key {0}'.format(test_key))


class TestTypeToolsIntable(unittest.TestCase):
    def test_success(self):
        test_key = 'int_key'
        self.assertTrue(type_tools.is_intable(BASE_CONFIG, test_key), 'Expect success for key {0}'.format(test_key))

    def test_failure(self):
        test_key = 'not_int_key'
        self.assertFalse(type_tools.is_intable(BASE_CONFIG, test_key), 'Expect failure for key {0}'.format(test_key))

    def test_nonexistent_key_failure(self):
        test_key = 'doesnt_exist'
        self.assertFalse(type_tools.is_intable(BASE_CONFIG, test_key),
                         'Expect failure for non-existent key {0}'.format(test_key))


class TestTypeToolsBoolable(unittest.TestCase):
    def test_word_true_success(self):
        test_key = 'bool_key_true'
        self.assertTrue(type_tools.is_boolable(BASE_CONFIG, test_key), 'Expect success for key {0}'.format(test_key))

    def test_word_false_success(self):
        test_key = 'bool_key_false'
        self.assertTrue(type_tools.is_boolable(BASE_CONFIG, test_key), 'Expect success for key {0}'.format(test_key))

    def test_number_zero_success(self):
        test_key = 'bool_key_num_zero'
        self.assertTrue(type_tools.is_boolable(BASE_CONFIG, test_key), 'Expect success for key {0}'.format(test_key))

    def test_num_one_success(self):
        test_key = 'bool_key_num_one'
        self.assertTrue(type_tools.is_boolable(BASE_CONFIG, test_key), 'Expect success for key {0}'.format(test_key))

    def test_num_two_success(self):
        test_key = 'bool_key_num_two'
        self.assertTrue(type_tools.is_boolable(BASE_CONFIG, test_key), 'Expect success for key {0}'.format(test_key))

    def test_word_zero_success(self):
        test_key = 'bool_key_word_zero'
        self.assertFalse(type_tools.is_boolable(BASE_CONFIG, test_key), 'Expect success for key {0}'.format(test_key))

    def test_nonsense_failure(self):
        test_key = 'not_bool_key'
        self.assertFalse(type_tools.is_boolable(BASE_CONFIG, test_key), 'Expect failure for key {0}'.format(test_key))

    def test_nonexistent_key_failure(self):
        test_key = 'doesnt_exist'
        self.assertFalse(type_tools.is_boolable(BASE_CONFIG, test_key),
                         'Expect failure for non-existent key {0}'.format(test_key))


if __name__ == '__main__':
    unittest.main()
