#
# Copyright (c) 2018 Duo Security
# All Rights Reserved
#
from duoauthproxy.lib.validation.connectivity import connectivity_results
from duoauthproxy.lib.config_provider import ConfigDict
from duoauthproxy.lib.validation.connectivity.check import cloud
from duoauthproxy.lib.validation.connectivity.connectivity_results import CloudResult

from ....base import ModuleConnectivityTest, MockConnectivityTestToolbox


class TestCheckCloud(ModuleConnectivityTest):

    def setUp(self):
        super(TestCheckCloud, self).setUp()

        self.BLANK_CONFIG = ConfigDict({})

        self.GOOD_CONFIG = ConfigDict({
            'ikey': 'thisisagoodikey',
            'skey': 'thisisagoodskey',
            'api_host': 'this.is.a.good.api.host',
        })

        self.GOOD_SECTION_RESULT = CloudResult(
            self.GOOD_PING_RESULT,
            self.GOOD_TIME_DRIFT_RESULT,
        )

        self.SUCCESS_TOOLBOX = MockConnectivityTestToolbox()

    def test_good_config(self):
        config = self.GOOD_CONFIG
        expected_result = self.GOOD_SECTION_RESULT
        actual_result = cloud.check_cloud(config, toolbox=self.SUCCESS_TOOLBOX)
        self.assertEqual(expected_result, actual_result)

    def test_blank_config(self):
        config = self.BLANK_CONFIG
        expected_result = CloudResult(
            connectivity_results.ConfigProblemSkippedTestResult(
                'ping', 'api_host'),
            connectivity_results.UnmetPrerequisiteSkippedTestResult(
                'time drift', 'ping'),
        )
        actual_result = cloud.check_cloud(config, toolbox=self.SUCCESS_TOOLBOX)
        self.assertEqual(expected_result, actual_result)


if __name__ == '__main__':
    import unittest
    unittest.main()
