#
# Copyright (c) 2018 Duo Security
# All Rights Reserved
#
import mock

from twisted.internet import defer

from ....base import ModuleConnectivityTest, MockConnectivityTestToolbox
from duoauthproxy.lib.validation.connectivity.check import radius_client
from duoauthproxy.lib.config_provider import ConfigDict
from duoauthproxy.lib.validation.connectivity.connectivity_results import (
    RadiusClientResult,
)


class TestCheckRadiusClient(ModuleConnectivityTest):
    def setUp(self):
        super(TestCheckRadiusClient, self).setUp()

        self.GOOD_CONFIG_RESULT = RadiusClientResult(
            self.GOOD_CONNECT_RADIUS_RESULT,
        )

        self.SUCCESS_TOOLBOX = MockConnectivityTestToolbox()

    @defer.inlineCallbacks
    def test_can_connect_all(self):
        expected_result = RadiusClientResult(
            [self.GOOD_CONNECT_RADIUS_RESULT, self.GOOD_CONNECT_RADIUS_RESULT]
        )

        config = ConfigDict({
            'host_1': '192.168.11.11',
            'host_2': '192.168.22.22',
            'secret': 'secret',
        })
        actual_result = yield radius_client.check_radius_client(config, toolbox=self.SUCCESS_TOOLBOX)
        self.assertEqual(expected_result,
                         actual_result,
                         "{0} and {1} should be equal".format(str(expected_result), str(actual_result)))

    @defer.inlineCallbacks
    def test_cant_connect(self):
        expected_result = RadiusClientResult(
            [self.BAD_CONNECT_RADIUS_RESULT, self.BAD_CONNECT_RADIUS_RESULT]
        )
        toolbox = MockConnectivityTestToolbox(fail_connect_radius=True)

        config = ConfigDict({
            'host_1': '192.168.11.11',
            'host_2': '192.168.22.22',
            'secret': 'secret',
        })
        actual_result = yield radius_client.check_radius_client(config, toolbox=toolbox)
        self.assertEqual(expected_result,
                         actual_result,
                         "{0} and {1} should be equal".format(str(expected_result), str(actual_result)))

    @defer.inlineCallbacks
    def test_mix_can_connect(self):
        mock_can_connect_radius = mock.Mock(side_effect=[self.BAD_CONNECT_RADIUS_RESULT, self.GOOD_CONNECT_RADIUS_RESULT])
        self.patch(MockConnectivityTestToolbox, 'test_connect_radius', mock_can_connect_radius)

        expected_result = RadiusClientResult(
            [self.BAD_CONNECT_RADIUS_RESULT, self.GOOD_CONNECT_RADIUS_RESULT]
        )

        config = ConfigDict({
            'host_1': '192.168.11.11',
            'host_2': '192.168.22.22',
            'secret': 'secret',
        })
        actual_result = yield radius_client.check_radius_client(config, toolbox=self.SUCCESS_TOOLBOX)
        self.assertEqual(expected_result,
                         actual_result,
                         "{0} and {1} should be equal".format(str(expected_result), str(actual_result)))


if __name__ == '__main__':
    import unittest
    unittest.main()
