import unittest
import time
import sys


class TimeLoggingTestResult(unittest.runner.TextTestResult):
    def __init__(self, *args, **kwargs):
        super(TimeLoggingTestResult, self).__init__(*args, **kwargs)
        self.test_timings = []
        self._test_started_at = None

    def startTest(self, test):
        self._test_started_at = time.time()
        super(TimeLoggingTestResult, self).startTest(test)

    def addSuccess(self, test):
        elapsed = time.time() - self._test_started_at
        name = unicode(test)
        self.test_timings.append((name, elapsed))
        super(TimeLoggingTestResult, self).addSuccess(test)

    def getTestTimings(self):
        return self.test_timings


class TimeLoggingTestRunner(unittest.TextTestRunner):
    def __init__(self, *args, **kwargs):
        self.slow_test_threshold = kwargs.get('slow_test_threshold', 0.3)
        super(TimeLoggingTestRunner, self).__init__(
            resultclass=TimeLoggingTestResult, *args,
            stream=kwargs.get('stream', sys.stderr),
            descriptions=kwargs.get('descriptions', True),
            verbosity=kwargs.get('verbosity', 1),
            failfast=kwargs.get('failfast', False),
            buffer=kwargs.get('buffer', False)
        )

    def run(self, test):
        result = super(TimeLoggingTestRunner, self).run(test)
        self.stream.writeln(
            "\nSlow Tests (>{:.03}s):".format(
                self.slow_test_threshold))
        for name, elapsed in sorted(result.getTestTimings(), key=lambda x: x[1], reverse=True):
            if elapsed > self.slow_test_threshold:
                self.stream.writeln(
                    "({:.03}s) {}".format(
                        elapsed, name))
        return result
